@@ -173,7 +173,7 @@ aesni_encrypt1(unsigned char *out, __m128i nv, const __m128i *rkeys)
     X(6);        \
     X(7)
 
-#define COUNTER_INC2(N) (*(uint32_t *) &(N)[12]) = (2U + (((*(uint32_t *) &(N)[12]))))
+#define COUNTER_INC2(N) (N)[3] += 2
 
 /* create a function of unrolling N ; the MAKEN is the unrolling
    macro, defined above. The N in MAKEN must match N, obviously. */
@@ -518,8 +518,8 @@ crypto_aead_aes256gcm_encrypt_afternm(unsigned char *c, unsigned long long *clen
     unsigned long long  i, j;
     unsigned long long  adlen_rnd64 = adlen & ~63ULL;
     unsigned long long  mlen_rnd128 = mlen & ~127ULL;
+    CRYPTO_ALIGN(16) uint32_t      n2[4];
     CRYPTO_ALIGN(16) unsigned char H[16];
-    CRYPTO_ALIGN(16) unsigned char n2[16];
     CRYPTO_ALIGN(16) unsigned char T[16];
     CRYPTO_ALIGN(16) unsigned char accum[16];
     CRYPTO_ALIGN(16) unsigned char fb[16];
@@ -529,13 +529,16 @@ crypto_aead_aes256gcm_encrypt_afternm(unsigned char *c, unsigned long long *clen
     if (mlen > 16ULL * (1ULL << 32)) {
         abort();
     }
-    memcpy(&n2[0], npub, 12);
-    *(uint32_t *) &n2[12] = 0x01000000;
+    memcpy(&n2[0], npub, 3 * 4);
+    n2[3] = 0x01000000;
     aesni_encrypt1(T, _mm_load_si128((const __m128i *) n2), rkeys);
-
-    (*(uint64_t *) &fb[0]) = _bswap64((uint64_t) (8 * adlen));
-    (*(uint64_t *) &fb[8]) = _bswap64((uint64_t) (8 * mlen));
-
+    {
+        uint64_t x;
+        x = _bswap64((uint64_t) (8 * adlen));
+        memcpy(&fb[0], &x, sizeof x);
+        x = _bswap64((uint64_t) (8 * mlen));
+        memcpy(&fb[8], &x, sizeof x);
+    }
     /* we store H (and it's power) byte-reverted once and for all */
     Hv = _mm_shuffle_epi8(_mm_load_si128((const __m128i *) H), rev);
     _mm_store_si128((__m128i *) H, Hv);
@@ -571,7 +574,7 @@ crypto_aead_aes256gcm_encrypt_afternm(unsigned char *c, unsigned long long *clen
         const int lb = iter * 16;                                                                    \
                                                                                                      \
         for (i = 0; i < mlen_rnd128; i += lb) {                                                      \
-            aesni_encrypt8full(c + i, (uint32_t *) n2, rkeys, m + i, accum, Hv, H2v, H3v, H4v, rev); \
+            aesni_encrypt8full(c + i, n2, rkeys, m + i, accum, Hv, H2v, H3v, H4v, rev);              \
         }                                                                                            \
     } while(0)
 
@@ -585,7 +588,7 @@ crypto_aead_aes256gcm_encrypt_afternm(unsigned char *c, unsigned long long *clen
             CRYPTO_ALIGN(16) unsigned char outni[8 * 16];    \
             unsigned long long mj = lb;                      \
                                                              \
-            aesni_encrypt8(outni, (uint32_t *) n2, rkeys);   \
+            aesni_encrypt8(outni, n2, rkeys);                \
             if ((i + mj) >= mlen) {                          \
                 mj = mlen - i;                               \
             }                                                \
@@ -603,7 +606,7 @@ crypto_aead_aes256gcm_encrypt_afternm(unsigned char *c, unsigned long long *clen
         }                                                    \
     } while(0)
 
-    n2[15] = 0;
+    n2[3] &= 0x00ffffff;
     COUNTER_INC2(n2);
     LOOPRND128;
     LOOPRMD128;
@@ -635,8 +638,8 @@ crypto_aead_aes256gcm_decrypt_afternm(unsigned char *m, unsigned long long *mlen
     unsigned long long  adlen_rnd64 = adlen & ~63ULL;
     unsigned long long  mlen;
     unsigned long long  mlen_rnd128;
+    CRYPTO_ALIGN(16) uint32_t      n2[4];
     CRYPTO_ALIGN(16) unsigned char H[16];
-    CRYPTO_ALIGN(16) unsigned char n2[16];
     CRYPTO_ALIGN(16) unsigned char T[16];
     CRYPTO_ALIGN(16) unsigned char accum[16];
     CRYPTO_ALIGN(16) unsigned char fb[16];
@@ -653,13 +656,16 @@ crypto_aead_aes256gcm_decrypt_afternm(unsigned char *m, unsigned long long *mlen
     }
     mlen = clen - 16;
 
-    memcpy(&n2[0], npub, 12);
-    *(uint32_t *) &n2[12] = 0x01000000;
+    memcpy(&n2[0], npub, 3 * 4);
+    n2[3] = 0x01000000;
     aesni_encrypt1(T, _mm_load_si128((const __m128i *) n2), rkeys);
-
-    (*(uint64_t *) &fb[0]) = _bswap64((uint64_t)(8 * adlen));
-    (*(uint64_t *) &fb[8]) = _bswap64((uint64_t)(8 * mlen));
-
+    {
+        uint64_t x;
+        x = _bswap64((uint64_t)(8 * adlen));
+        memcpy(&fb[0], &x, sizeof x);
+        x = _bswap64((uint64_t)(8 * mlen));
+        memcpy(&fb[8], &x, sizeof x);
+    }
     memcpy(H, ctx->H, sizeof H);
     Hv = _mm_shuffle_epi8(_mm_load_si128((const __m128i *) H), rev);
     _mm_store_si128((__m128i *) H, Hv);
@@ -702,7 +708,7 @@ crypto_aead_aes256gcm_decrypt_afternm(unsigned char *m, unsigned long long *mlen
         const int lb = iter * 16;                                                                 \
                                                                                                   \
         for (i = 0; i < mlen_rnd128; i += lb) {                                                   \
-            aesni_decrypt8full(m + i, (uint32_t *) n2, rkeys, c + i);                             \
+            aesni_decrypt8full(m + i, n2, rkeys, c + i);                                          \
         }                                                                                         \
     } while(0)
 
@@ -740,13 +746,13 @@ crypto_aead_aes256gcm_decrypt_afternm(unsigned char *m, unsigned long long *mlen
             if ((i + mj) >= mlen) {                          \
                 mj = mlen - i;                               \
             }                                                \
-            aesni_encrypt8(outni, (uint32_t *) n2, rkeys);   \
+            aesni_encrypt8(outni, n2, rkeys);                \
             for (j = 0; j < mj; j++) {                       \
                 m[i + j] = c[i + j] ^ outni[j];              \
             }                                                \
         }                                                    \
     } while(0)
-    n2[15] = 0;
+    n2[3] &= 0x00ffffff;
 
     COUNTER_INC2(n2);
     LOOPACCUMDRND128;
@@ -762,7 +768,7 @@ crypto_aead_aes256gcm_decrypt_afternm(unsigned char *m, unsigned long long *mlen
             return -1;
         }
     }
-    *(uint32_t *) &n2[12] = 0;
+    n2[3] = 0U;
     COUNTER_INC2(n2);
     LOOPDRND128;
     LOOPDRMD128;
