@@ -10,6 +10,11 @@ crypto_generichash_blake2b_bytes_max(void) {
     return crypto_generichash_blake2b_BYTES_MAX;
 }
 
+size_t
+crypto_generichash_blake2b_bytes(void) {
+    return crypto_generichash_blake2b_BYTES;
+}
+
 size_t
 crypto_generichash_blake2b_keybytes_min(void) {
     return crypto_generichash_blake2b_KEYBYTES_MIN;
@@ -21,21 +26,16 @@ crypto_generichash_blake2b_keybytes_max(void) {
 }
 
 size_t
-crypto_generichash_blake2b_blockbytes(void) {
-    return crypto_generichash_blake2b_BLOCKBYTES;
+crypto_generichash_blake2b_keybytes(void) {
+    return crypto_generichash_blake2b_KEYBYTES;
 }
 
 size_t
-crypto_generichash_blake2b_salt_bytes(void) {
+crypto_generichash_blake2b_saltbytes(void) {
     return crypto_generichash_blake2b_SALTBYTES;
 }
 
 size_t
-crypto_generichash_blake2b_personal_bytes(void) {
+crypto_generichash_blake2b_personalbytes(void) {
     return crypto_generichash_blake2b_PERSONALBYTES;
 }
-
-const char *
-crypto_generichash_blake2b_blockbytes_primitive(void) {
-    return "blake2b";
-}
