@@ -11,6 +11,7 @@
    this software. If not, see <http://creativecommons.org/publicdomain/zero/1.0/>.
 */
 
+#include <assert.h>
 #include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
@@ -19,6 +20,14 @@
 #include "blake2-impl.h"
 #include "runtime.h"
 
+#ifdef HAVE_TI_MODE
+# if defined(__SIZEOF_INT128__)
+typedef unsigned __int128 uint128_t;
+# else
+typedef unsigned uint128_t __attribute__((mode(TI)));
+# endif
+#endif
+
 static blake2b_compress_fn blake2b_compress = blake2b_compress_ref;
 
 static const uint64_t blake2b_IV[8] =
@@ -62,8 +71,8 @@ static inline int blake2b_clear_lastblock( blake2b_state *S )
 #endif
 static inline int blake2b_increment_counter( blake2b_state *S, const uint64_t inc )
 {
-#if defined(__x86_64__) && defined(__SIZEOF_INT128__)
-  __uint128_t t = ( ( __uint128_t )S->t[1] << 64 ) | S->t[0];
+#ifdef HAVE_TI_MODE
+  uint128_t t = ( ( uint128_t )S->t[1] << 64 ) | S->t[0];
   t += inc;
   S->t[0] = ( uint64_t )( t >>  0 );
   S->t[1] = ( uint64_t )( t >> 64 );
@@ -160,7 +169,7 @@ int blake2b_init( blake2b_state *S, const uint8_t outlen )
 {
   blake2b_param P[1];
 
-  if ( ( !outlen ) || ( outlen > BLAKE2B_OUTBYTES ) ) return -1;
+  if ( ( !outlen ) || ( outlen > BLAKE2B_OUTBYTES ) ) abort();
 
   P->digest_length = outlen;
   P->key_length    = 0;
@@ -181,7 +190,7 @@ int blake2b_init_salt_personal( blake2b_state *S, const uint8_t outlen,
 {
   blake2b_param P[1];
 
-  if ( ( !outlen ) || ( outlen > BLAKE2B_OUTBYTES ) ) return -1;
+  if ( ( !outlen ) || ( outlen > BLAKE2B_OUTBYTES ) ) abort();
 
   P->digest_length = outlen;
   P->key_length    = 0;
@@ -209,9 +218,9 @@ int blake2b_init_key( blake2b_state *S, const uint8_t outlen, const void *key, c
 {
   blake2b_param P[1];
 
-  if ( ( !outlen ) || ( outlen > BLAKE2B_OUTBYTES ) ) return -1;
+  if ( ( !outlen ) || ( outlen > BLAKE2B_OUTBYTES ) ) abort();
 
-  if ( !key || !keylen || keylen > BLAKE2B_KEYBYTES ) return -1;
+  if ( !key || !keylen || keylen > BLAKE2B_KEYBYTES ) abort();
 
   P->digest_length = outlen;
   P->key_length    = keylen;
@@ -225,7 +234,7 @@ int blake2b_init_key( blake2b_state *S, const uint8_t outlen, const void *key, c
   memset( P->salt,     0, sizeof( P->salt ) );
   memset( P->personal, 0, sizeof( P->personal ) );
 
-  if( blake2b_init_param( S, P ) < 0 ) return -1;
+  if( blake2b_init_param( S, P ) < 0 ) abort();
 
   {
     uint8_t block[BLAKE2B_BLOCKBYTES];
@@ -242,9 +251,9 @@ int blake2b_init_key_salt_personal( blake2b_state *S, const uint8_t outlen, cons
 {
   blake2b_param P[1];
 
-  if ( ( !outlen ) || ( outlen > BLAKE2B_OUTBYTES ) ) return -1;
+  if ( ( !outlen ) || ( outlen > BLAKE2B_OUTBYTES ) ) abort();
 
-  if ( !key || !keylen || keylen > BLAKE2B_KEYBYTES ) return -1;
+  if ( !key || !keylen || keylen > BLAKE2B_KEYBYTES ) abort();
 
   P->digest_length = outlen;
   P->key_length    = keylen;
@@ -266,7 +275,7 @@ int blake2b_init_key_salt_personal( blake2b_state *S, const uint8_t outlen, cons
     memset( P->personal, 0, sizeof( P->personal ) );
   }
 
-  if( blake2b_init_param( S, P ) < 0 ) return -1;
+  if( blake2b_init_param( S, P ) < 0 ) abort();
 
   {
     uint8_t block[BLAKE2B_BLOCKBYTES];
@@ -312,14 +321,15 @@ int blake2b_update( blake2b_state *S, const uint8_t *in, uint64_t inlen )
 int blake2b_final( blake2b_state *S, uint8_t *out, uint8_t outlen )
 {
   if( !outlen || outlen > BLAKE2B_OUTBYTES ) {
-    return -1;
+    abort();
   }
   if( S->buflen > BLAKE2B_BLOCKBYTES )
   {
     blake2b_increment_counter( S, BLAKE2B_BLOCKBYTES );
     blake2b_compress( S, S->buf );
     S->buflen -= BLAKE2B_BLOCKBYTES;
-    memmove( S->buf, S->buf + BLAKE2B_BLOCKBYTES, S->buflen );
+    assert( S->buflen <= BLAKE2B_BLOCKBYTES );
+    memcpy( S->buf, S->buf + BLAKE2B_BLOCKBYTES, S->buflen );
   }
 
   blake2b_increment_counter( S, S->buflen );
@@ -348,23 +358,23 @@ int blake2b( uint8_t *out, const void *in, const void *key, const uint8_t outlen
   blake2b_state S[1];
 
   /* Verify parameters */
-  if( NULL == in && inlen > 0 ) return -1;
+  if( NULL == in && inlen > 0 ) abort();
 
-  if( NULL == out ) return -1;
+  if( NULL == out ) abort();
 
-  if( !outlen || outlen > BLAKE2B_OUTBYTES ) return -1;
+  if( !outlen || outlen > BLAKE2B_OUTBYTES ) abort();
 
-  if( NULL == key && keylen > 0 ) return -1;
+  if( NULL == key && keylen > 0 ) abort();
 
-  if( keylen > BLAKE2B_KEYBYTES ) return -1;
+  if( keylen > BLAKE2B_KEYBYTES ) abort();
 
   if( keylen > 0 )
   {
-    if( blake2b_init_key( S, outlen, key, keylen ) < 0 ) return -1;
+    if( blake2b_init_key( S, outlen, key, keylen ) < 0 ) abort();
   }
   else
   {
-    if( blake2b_init( S, outlen ) < 0 ) return -1;
+    if( blake2b_init( S, outlen ) < 0 ) abort();
   }
 
   blake2b_update( S, ( const uint8_t * )in, inlen );
@@ -378,23 +388,23 @@ int blake2b_salt_personal( uint8_t *out, const void *in, const void *key, const
   blake2b_state S[1];
 
   /* Verify parameters */
-  if( NULL == in && inlen > 0 ) return -1;
+  if( NULL == in && inlen > 0 ) abort();
 
-  if( NULL == out ) return -1;
+  if( NULL == out ) abort();
 
-  if( !outlen || outlen > BLAKE2B_OUTBYTES ) return -1;
+  if( !outlen || outlen > BLAKE2B_OUTBYTES ) abort();
 
-  if( NULL == key && keylen > 0 ) return -1;
+  if( NULL == key && keylen > 0 ) abort();
 
-  if( keylen > BLAKE2B_KEYBYTES ) return -1;
+  if( keylen > BLAKE2B_KEYBYTES ) abort();
 
   if( keylen > 0 )
   {
-    if( blake2b_init_key_salt_personal( S, outlen, key, keylen, salt, personal ) < 0 ) return -1;
+    if( blake2b_init_key_salt_personal( S, outlen, key, keylen, salt, personal ) < 0 ) abort();
   }
   else
   {
-    if( blake2b_init_salt_personal( S, outlen, salt, personal ) < 0 ) return -1;
+    if( blake2b_init_salt_personal( S, outlen, salt, personal ) < 0 ) abort();
   }
 
   blake2b_update( S, ( const uint8_t * )in, inlen );
