@@ -6,8 +6,8 @@ Public domain.
 
 #include <stdint.h>
 
-#include "api.h"
 #include "crypto_core_salsa20.h"
+#include "crypto_stream_salsa20.h"
 #include "utils.h"
 
 #ifndef HAVE_AMD64_ASM
