@@ -54,7 +54,8 @@ int crypto_box_keypair(unsigned char *pk, unsigned char *sk);
 SODIUM_EXPORT
 int crypto_box_easy(unsigned char *c, const unsigned char *m,
                     unsigned long long mlen, const unsigned char *n,
-                    const unsigned char *pk, const unsigned char *sk);
+                    const unsigned char *pk, const unsigned char *sk)
+            __attribute__ ((warn_unused_result));
 
 SODIUM_EXPORT
 int crypto_box_open_easy(unsigned char *m, const unsigned char *c,
@@ -66,7 +67,8 @@ SODIUM_EXPORT
 int crypto_box_detached(unsigned char *c, unsigned char *mac,
                         const unsigned char *m, unsigned long long mlen,
                         const unsigned char *n, const unsigned char *pk,
-                        const unsigned char *sk);
+                        const unsigned char *sk)
+            __attribute__ ((warn_unused_result));
 
 SODIUM_EXPORT
 int crypto_box_open_detached(unsigned char *m, const unsigned char *c,
@@ -85,7 +87,8 @@ size_t  crypto_box_beforenmbytes(void);
 
 SODIUM_EXPORT
 int crypto_box_beforenm(unsigned char *k, const unsigned char *pk,
-                        const unsigned char *sk);
+                        const unsigned char *sk)
+            __attribute__ ((warn_unused_result));
 
 SODIUM_EXPORT
 int crypto_box_easy_afternm(unsigned char *c, const unsigned char *m,
@@ -139,7 +142,8 @@ size_t  crypto_box_boxzerobytes(void);
 SODIUM_EXPORT
 int crypto_box(unsigned char *c, const unsigned char *m,
                unsigned long long mlen, const unsigned char *n,
-               const unsigned char *pk, const unsigned char *sk);
+               const unsigned char *pk, const unsigned char *sk)
+            __attribute__ ((warn_unused_result));
 
 SODIUM_EXPORT
 int crypto_box_open(unsigned char *m, const unsigned char *c,
