@@ -27,7 +27,8 @@ int crypto_scalarmult_base(unsigned char *q, const unsigned char *n);
 
 SODIUM_EXPORT
 int crypto_scalarmult(unsigned char *q, const unsigned char *n,
-                      const unsigned char *p);
+                      const unsigned char *p)
+            __attribute__ ((warn_unused_result));
 
 #ifdef __cplusplus
 }
