@@ -20,7 +20,7 @@
 #endif
 
 #include "crypto_core_salsa20.h"
-#include "crypto_auth_hmacsha512256.h"
+#include "crypto_generichash.h"
 #include "crypto_stream_salsa20.h"
 #include "randombytes.h"
 #include "randombytes_salsa20_random.h"
@@ -38,14 +38,17 @@ BOOLEAN NTAPI RtlGenRandom(PVOID RandomBuffer, ULONG RandomBufferLength);
 #endif
 
 #define SALSA20_RANDOM_BLOCK_SIZE crypto_core_salsa20_OUTPUTBYTES
-#define SHA512_BLOCK_SIZE 128U
-#define SHA512_MIN_PAD_SIZE (1U + 16U)
+#define HASH_BLOCK_SIZE 128U
 #define COMPILER_ASSERT(X) (void) sizeof(char[(X) ? 1 : -1])
 
 #if defined(__OpenBSD__) || defined(__CloudABI__)
 # define HAVE_SAFE_ARC4RANDOM 1
 #endif
 
+#ifndef SSIZE_MAX
+# define SSIZE_MAX (SIZE_MAX / 2 - 1)
+#endif
+
 typedef struct Salsa20Random_ {
     unsigned char key[crypto_stream_salsa20_KEYBYTES];
     unsigned char rnd32[16U * SALSA20_RANDOM_BLOCK_SIZE];
@@ -98,6 +101,7 @@ safe_read(const int fd, void * const buf_, size_t size)
     ssize_t        readnb;
 
     assert(size > (size_t) 0U);
+    assert(size <= SSIZE_MAX);
     do {
         while ((readnb = read(fd, buf, size)) < (ssize_t) 0 &&
                (errno == EINTR || errno == EAGAIN));  /* LCOV_EXCL_LINE */
@@ -251,18 +255,19 @@ randombytes_salsa20_random_rekey(const unsigned char * const mix)
     }
 }
 
-void
+static void
 randombytes_salsa20_random_stir(void)
 {
-    const unsigned char s[crypto_auth_hmacsha512256_KEYBYTES] = {
-        'T', 'h', 'i', 's', 'I', 's', 'J', 'u', 's', 't', 'A', 'T',
-        'h', 'i', 'r', 't', 'y', 'T', 'w', 'o', 'B', 'y', 't', 'e',
-        's', 'S', 'e', 'e', 'd', '.', '.', '.'
+    /* constant to personalize the hash function */
+    const unsigned char hsigma[crypto_generichash_KEYBYTES] = {
+        0x54, 0x68, 0x69, 0x73, 0x49, 0x73, 0x4a, 0x75,
+        0x73, 0x74, 0x41, 0x54, 0x68, 0x69, 0x72, 0x74,
+        0x79, 0x54, 0x77, 0x6f, 0x42, 0x79, 0x74, 0x65,
+        0x73, 0x53, 0x65, 0x65, 0x64, 0x2e, 0x2e, 0x2e
     };
-    unsigned char  m0[crypto_auth_hmacsha512256_BYTES +
-                      2U * SHA512_BLOCK_SIZE - SHA512_MIN_PAD_SIZE];
-    unsigned char *k0 = m0 + crypto_auth_hmacsha512256_BYTES;
-    size_t         sizeof_k0 = sizeof m0 - crypto_auth_hmacsha512256_BYTES;
+    unsigned char  m0[crypto_stream_salsa20_KEYBYTES + HASH_BLOCK_SIZE];
+    unsigned char *k0 = m0 + crypto_stream_salsa20_KEYBYTES;
+    size_t         sizeof_k0 = sizeof m0 - crypto_stream_salsa20_KEYBYTES;
 
     memset(stream.rnd32, 0, sizeof stream.rnd32);
     stream.rnd32_outleft = (size_t) 0U;
@@ -297,8 +302,10 @@ randombytes_salsa20_random_stir(void)
         abort(); /* LCOV_EXCL_LINE */
     }
 #endif
-    COMPILER_ASSERT(sizeof stream.key == crypto_auth_hmacsha512256_BYTES);
-    crypto_auth_hmacsha512256(stream.key, k0, sizeof_k0, s);
+    if (crypto_generichash(stream.key, sizeof stream.key, k0, sizeof_k0,
+                           hsigma, sizeof hsigma) != 0) {
+        abort();
+    }
     COMPILER_ASSERT(sizeof stream.key <= sizeof m0);
     randombytes_salsa20_random_rekey(m0);
     sodium_memzero(m0, sizeof m0);
@@ -323,35 +330,7 @@ randombytes_salsa20_random_stir_if_needed(void)
 #endif
 }
 
-static uint32_t
-randombytes_salsa20_random_getword(void)
-{
-    uint32_t val;
-    int      ret;
-
-    COMPILER_ASSERT(sizeof stream.rnd32 >= (sizeof stream.key) + (sizeof val));
-    COMPILER_ASSERT(((sizeof stream.rnd32) - (sizeof stream.key))
-                    % sizeof val == (size_t) 0U);
-    if (stream.rnd32_outleft <= (size_t) 0U) {
-        randombytes_salsa20_random_stir_if_needed();
-        COMPILER_ASSERT(sizeof stream.nonce == crypto_stream_salsa20_NONCEBYTES);
-        ret = crypto_stream_salsa20((unsigned char *) stream.rnd32,
-                                    (unsigned long long) sizeof stream.rnd32,
-                                    (unsigned char *) &stream.nonce,
-                                    stream.key);
-        assert(ret == 0);
-        stream.rnd32_outleft = (sizeof stream.rnd32) - (sizeof stream.key);
-        randombytes_salsa20_random_rekey(&stream.rnd32[stream.rnd32_outleft]);
-        stream.nonce++;
-    }
-    stream.rnd32_outleft -= sizeof val;
-    memcpy(&val, &stream.rnd32[stream.rnd32_outleft], sizeof val);
-    memset(&stream.rnd32[stream.rnd32_outleft], 0, sizeof val);
-
-    return val;
-}
-
-int
+static int
 randombytes_salsa20_random_close(void)
 {
     int ret = -1;
@@ -386,13 +365,7 @@ randombytes_salsa20_random_close(void)
     return ret;
 }
 
-uint32_t
-randombytes_salsa20_random(void)
-{
-    return randombytes_salsa20_random_getword();
-}
-
-void
+static void
 randombytes_salsa20_random_buf(void * const buf, const size_t size)
 {
     size_t i;
@@ -415,7 +388,41 @@ randombytes_salsa20_random_buf(void * const buf, const size_t size)
                               (unsigned char *) &stream.nonce, stream.key);
 }
 
-const char *
+static uint32_t
+randombytes_salsa20_random_getword(void)
+{
+    uint32_t val;
+    int      ret;
+
+    COMPILER_ASSERT(sizeof stream.rnd32 >= (sizeof stream.key) + (sizeof val));
+    COMPILER_ASSERT(((sizeof stream.rnd32) - (sizeof stream.key))
+                    % sizeof val == (size_t) 0U);
+    if (stream.rnd32_outleft <= (size_t) 0U) {
+        randombytes_salsa20_random_stir_if_needed();
+        COMPILER_ASSERT(sizeof stream.nonce == crypto_stream_salsa20_NONCEBYTES);
+        ret = crypto_stream_salsa20((unsigned char *) stream.rnd32,
+                                    (unsigned long long) sizeof stream.rnd32,
+                                    (unsigned char *) &stream.nonce,
+                                    stream.key);
+        assert(ret == 0);
+        stream.rnd32_outleft = (sizeof stream.rnd32) - (sizeof stream.key);
+        randombytes_salsa20_random_rekey(&stream.rnd32[stream.rnd32_outleft]);
+        stream.nonce++;
+    }
+    stream.rnd32_outleft -= sizeof val;
+    memcpy(&val, &stream.rnd32[stream.rnd32_outleft], sizeof val);
+    memset(&stream.rnd32[stream.rnd32_outleft], 0, sizeof val);
+
+    return val;
+}
+
+static uint32_t
+randombytes_salsa20_random(void)
+{
+    return randombytes_salsa20_random_getword();
+}
+
+static const char *
 randombytes_salsa20_implementation_name(void)
 {
     return "salsa20";
