@@ -27,8 +27,11 @@
 # define rand(X) arc4random(X)
 #endif
 
+int xmain(void);
+
+#ifndef BROWSER_TESTS
+
 FILE *fp_res;
-int   xmain(void);
 
 int main(void)
 {
@@ -61,6 +64,24 @@ int main(void)
 
 #undef  printf
 #define printf(...) fprintf(fp_res, __VA_ARGS__)
+
+#else
+
+int main(void)
+{
+    if (sodium_init() != 0) {
+        return 99;
+    }
+    if (xmain() != 0) {
+        return 99;
+    }
+    printf("--- SUCCESS ---\n");
+
+    return 0;
+}
+
+#endif
+
 #define main xmain
 
 #endif
